==> linktools-0.8.15rc0-py3-none-any.whl: linktools/metadata.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
@author  : Hu Ji
@file    : meta.py
@time    : 2018/11/25
@site    :
@software: PyCharm

              ,----------------,              ,---------,
         ,-----------------------,          ,"        ,"|
       ,"                      ,"|        ,"        ,"  |
      +-----------------------+  |      ,"        ,"    |
      |  .-----------------.  |  |     +---------+      |
      |  |                 |  |  |     | -==----'|      |
      |  | $ sudo rm -rf / |  |  |     |         |      |
      |  |                 |  |  |/----|`---=    |      |
      |  |                 |  |  |   ,/|==== ooo |      ;
      |  |                 |  |  |  // |(((( [33]|    ,"
      |  `-----------------'  |," .;'| |((((     |  ,"
      +-----------------------+  ;;  | |         |,"
         /_)______________(_/  //'   | +---------+
    ___________________________/___  `,
   /  oooooooooooooooo  .o.  oooo /,   `,"-----------
  / ==ooooooooooooooo==.o.  ooo= //   ,``--{)B     ,"
 /_==__==========__==_ooo__ooo=_/'   /___________,"
"""


class __MissingType:
    __eq__ = lambda l, r: \
        l is r or type(l) is type(r)
    __repr__ = lambda _: "__missing__"
    __bool__ = lambda _: False


__name__ = "linktools"
__release__ = True
__version__ = "0.8.15rc0"
__ep_group__ = "linktools_scripts"
__missing__ = __MissingType()
__description__ = f"""\
    ___       __   __              __
   / (_)___  / /__/ /_____  ____  / /____
  / / / __ \\/ //_/ __/ __ \\/ __ \\/ / ___/  linktools toolkit (v0.8.15rc0)
 / / / / / / ,< / /_/ /_/ / /_/ / (__  )   by: Hu Ji <669898595@qq.com>
/_/_/_/ /_/_/|_|\\__/\\____/\\____/_/____/
"""

==> linktools-0.8.16-py3-none-any.whl: linktools/metadata.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
@author  : Hu Ji
@file    : meta.py
@time    : 2018/11/25
@site    :
@software: PyCharm

              ,----------------,              ,---------,
         ,-----------------------,          ,"        ,"|
       ,"                      ,"|        ,"        ,"  |
      +-----------------------+  |      ,"        ,"    |
      |  .-----------------.  |  |     +---------+      |
      |  |                 |  |  |     | -==----'|      |
      |  | $ sudo rm -rf / |  |  |     |         |      |
      |  |                 |  |  |/----|`---=    |      |
      |  |                 |  |  |   ,/|==== ooo |      ;
      |  |                 |  |  |  // |(((( [33]|    ,"
      |  `-----------------'  |," .;'| |((((     |  ,"
      +-----------------------+  ;;  | |         |,"
         /_)______________(_/  //'   | +---------+
    ___________________________/___  `,
   /  oooooooooooooooo  .o.  oooo /,   `,"-----------
  / ==ooooooooooooooo==.o.  ooo= //   ,``--{)B     ,"
 /_==__==========__==_ooo__ooo=_/'   /___________,"
"""

###################################################################
# metadata
###################################################################

__name__ = "linktools"
__version__ = "0.8.16"
__release__ = True
__develop__ = False
__ep_scripts__ = "linktools_scripts"
__ep_updater__ = "linktools_updater"
__description__ = f"""\
    ___       __   __              __
   / (_)___  / /__/ /_____  ____  / /____
  / / / __ \\/ //_/ __/ __ \\/ __ \\/ / ___/  linktools toolkit (v0.8.16)
 / / / / / / ,< / /_/ /_/ / /_/ / (__  )   by: Hu Ji <669898595@qq.com>
/_/_/_/ /_/_/|_|\\__/\\____/\\____/_/____/
"""

###################################################################
# other
###################################################################

class __MissingType:
    __eq__ = lambda l, r: \
        l is r or type(l) is type(r)
    __repr__ = lambda _: "__missing__"
    __bool__ = lambda _: False

__missing__ = __MissingType()

del __MissingType
